@@ -129,8 +129,8 @@ def crosssection_vv_fho(g: float, T: float, idata: np.ndarray, molecule1: Molecu
         raise KineticlibError('VV transition with no change in vibrational level specified')
 
 
-def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecule: Molecule, i: int,
-                                   center_of_mass: bool=True, vl_dependent: bool=True) -> float:
+def crosssection_diss(g: float, T: float, idata: np.ndarray, molecule: Molecule, i: int,
+                      center_of_mass: bool=True, vl_dependent: bool=True) -> float:
     """Calculates the dissociation crosssection either using the rigid sphere model or the rigid sphere
     model depending on the relative energy along the center-of-mass line for the process
     **AB(i) + P -> A + B + P**
@@ -297,8 +297,8 @@ def vv_integral_fho(T: float, deg: int, idata: np.ndarray, molecule1: Molecule,
                                          molecule2.vibr[k], molecule2.vibr[k - i_delta], i, k, i_delta, nokt)
 
 
-def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule: Molecule, i: int,
-                               center_of_mass: bool=True, vl_dependent: bool=True, nokt: bool=False) -> float:
+def diss_integral(T: float, deg: int, idata: np.ndarray, molecule: Molecule, i: int,
+                  center_of_mass: bool=True, vl_dependent: bool=True, nokt: bool=False) -> float:
     """Calculates the generalized dissociation omega integral either using the rigid sphere model or the rigid sphere
     model depending on the relative energy along the center-of-mass line for the process
     **AB(i) + P -> A + B + P**
