@@ -47,7 +47,7 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infc
             * 'VHS' (Variable Hard Sphere model)
             * the rigid sphere model will be used otherwise
 
-        defaults to 'VSS'
+        defaults to `'VSS'`
 
     Returns
     -------
@@ -119,7 +119,7 @@ def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: Molecule,
             * 'VHS' (Variable Hard Sphere model)
             * the rigid sphere model will be used otherwise
 
-        defaults to 'VSS'
+        defaults to `'VSS'`
 
     Returns
     -------
@@ -149,7 +149,7 @@ def Zr(T: float, idata: np.ndarray, molecule: Molecule, infcoll: float, model: s
             * 'VHS' (Variable Hard Sphere model)
             * the rigid sphere model will be used otherwise
 
-        defaults to 'VSS'
+        defaults to `'VSS'`
 
     Returns
     -------
@@ -350,7 +350,7 @@ def raw_rot_rel_time_VSS(T: float, collision_mass: float, eps: float, vssc: floa
             * 'VHS' (Variable Hard Sphere model)
             * the Rigid Sphere model will be used otherwise
 
-        defaults to 'VSS'
+        defaults to `'VSS'`
 
     Returns
     -------
@@ -392,7 +392,7 @@ def raw_Zr(T: float, collision_mass: float, eps: float, vsso: float, vssc_deflec
             * 'VHS' (Variable Hard Sphere model)
             * the Rigid Sphere model will be used otherwise
 
-        defaults to 'VSS'
+        defaults to `'VSS'`
 
     Returns
     -------
